*******************
Doc de ``matching``
*******************


Voici l'autodocumentation d'un package/module

Elastic
=======

.. automodule:: matching.elastic
   :members:

Search
======

.. automodule:: matching.search
   :members:

